@@ -3,7 +3,7 @@
 import asyncio
 import os
 import traceback
-from typing import Awaitable, Callable
+from typing import Any, Awaitable, Callable
 
 from gv_pubsub.pubsub import PubSub
 from gv_requests.requests import Requests
@@ -139,10 +139,13 @@ class Service:
                                                         sampling, frompointeid, topointeid)
 
     @staticmethod
-    async def _get_not_empty(get_coro):
+    async def _get_not_empty(get_func: Callable, args: tuple = (), kwargs: dict = None) -> Any:
+        if kwargs is None:
+            kwargs = {}
+
         res = {}
         while len(res) == 0:
-            res = await get_coro
+            res = await get_func(*args, **kwargs)
         return res
 
 
