@@ -5,7 +5,6 @@ class DbColumn:
     separator = '.'
 
     att = 'att'
-    classification = 'classification'
     confidence = 'confidence'
     datapoint = 'data_point'
     datatype = 'data_type'
@@ -22,11 +21,15 @@ class DbColumn:
     fromzonepoint = 'from_zone_point'
     geom = 'geom'
     id = 'id'
-    imputedindicator = 'imputed_indicator'
     indicator = 'indicator'
+    nbike = 'nbike'
+    nbus = 'nbus'
+    ncar = 'ncar'
     networkdataquality = 'network_data_quality'
     networkindicator = 'network_indicator'
     occupancy = 'occupancy'
+    prediction = 'prediction'
+    predictionpoint = 'prediction_point'
     ratio = 'ratio'
     road = 'road'
     roadcenter = 'road_center'
@@ -47,11 +50,12 @@ class DbColumn:
 class DbTable:
     datapoint = 'data_point'
     datapointdataquality = 'data_point_data_quality'
-    datapointimputedindicator = 'data_point_imputed_indicator'
     datapointindicator = 'data_point_indicator'
     datatype = 'data_type'
     networkdataquality = 'network_data_quality'
     networkindicator = 'network_indicator'
+    prediction = 'prediction'
+    predictionpoint = 'prediction_point'
     road = 'road'
     roadcenter = 'road_center'
     roaddatapoint = 'road_data_point'
@@ -86,13 +90,15 @@ class MessageData(DbColumn):
     hendday = 21
     hstartday = 6
 
+    avg = 'avg'
     max = 'max'
-    mean = 'mean'
     min = 'min'
+    raw = 'raw'
 
 
 class AttId(DbColumn):
     centerxy = 'centerxy'
+    centroid = 'centroid'
     datapointseids = 'datapoints'
     datatypeeid = 'datatypeeid'
     ffspeed = 'ffspeed'
@@ -108,6 +114,8 @@ class AttId(DbColumn):
     no = 'no'
     roads = 'roads'
     tono = 'tono'
+    x = 'x'
+    y = 'y'
     zone = 'zone'
 
 
@@ -123,8 +131,6 @@ class MessageKind:
 
     past = 'past'
 
-    imputed = 'imputed'
-
     dataquality = 'dataquality'
     datapoint = 'datapoint'
     datatype = 'datatype'
@@ -132,6 +138,8 @@ class MessageKind:
     mappingroadsdatapoints = 'mappingroadsdatapoints'
     network = 'network'
     partitions = 'partitions'
+    prediction = 'prediction'
+    predictionpoint = 'predictionpoint'
     traveltime = 'traveltime'
     turnratio = 'turnratio'
     vehicles = 'vehicles'
